==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/ar-SA/admin/models/message.php <==
<?php

return array(

    'deleted' => 'نموذج الأصول المحذوفة',
    'does_not_exist' => 'الموديل غير موجود.',
    'no_association' => 'تحذير! نموذج الأصول لهذا العنصر غير صالح أو مفقود!',
    'no_association_fix' => 'سيؤدي هذا إلى كسر الأمور بطرق غريبة وفظيعة. قم بتعديل هذا الأصل الآن لربطه بنموذج.',
    'assoc_users'	 => 'هذا الموديل مرتبط حاليا بواحد أو أكثر من الأصول ولا يمكن حذفه. يرجى حذف الأصول، ثم محاولة الحذف مرة أخرى. ',


    'create' => array(
        'error'   => 'لم يتم انشاء الموديل، يرجى إعادة المحاولة.',
        'success' => 'تم إنشاء الموديل بنجاح.',
        'duplicate_set' => 'يوجد مسبقا موديل بهذا الاسم، الشركة المصنعة ورقم الموديل.',
    ),

    'update' => array(
        'error'   => 'لم يتم تحديث الموديل، يرجى إعادة المحاولة',
        'success' => 'تم تحديث الموديل بنجاح.',
    ),

    'delete' => array(
        'confirm'   => 'هل تريد بالتأكيد حذف موديل الأصل هذا؟',
        'error'   => 'حدثت مشكلة أثناء حذف الموديل. حاول مرة اخرى.',
        'success' => 'تم حذف الموديل بنجاح.'
    ),

    'restore' => array(
        'error'   		=> 'لم تتم استعادة الموديل، يرجى إعادة المحاولة',
        'success' 		=> 'تم إستعادة الموديل بنجاح.'
    ),

    'bulkedit' => array(
        'error'   		=> 'لم يتم تغيير أي حقول، لذلك لم يتم تحديث أي شيء.',
        'success' 		=> 'تم تحديث النموذج بنجاح. |تم تحديث :model_count نموذج بنجاح.',
        'warn'          => 'أنت على وشك تحديث خصائص النموذج التالي model: |أنت على وشك تعديل خصائص :model_count models:',

    ),

    'bulkdelete' => array(
        'error'   		    => 'لم يتم اختيار أي موديلات، لذلك لم يتم حذف أي شيء.',
        'success' 		    => 'تم حذف النموذج!|تم حذف :success_count نموذج!',
        'success_partial' 	=> 'تم حذف:success_count: من الموديلات، ومع ذلك تعذر حذف fail_count: نظرًا لأنها لا تزال تحتوي على أصول مقترنة بها.'
    ),

);

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/ar-SA/admin/models/message.php <==
<?php

return array(

    'deleted' => 'نموذج الأصول المحذوفة',
    'does_not_exist' => 'الموديل غير موجود.',
    'no_association' => 'تحذير! نموذج الأصول لهذا العنصر غير صالح أو مفقود!',
    'no_association_fix' => 'سيؤدي هذا إلى كسر الأمور بطرق غريبة وفظيعة. قم بتعديل هذا الأصل الآن لربطه بنموذج.',
    'assoc_users'	 => 'هذا الموديل مرتبط حاليا بواحد أو أكثر من الأصول ولا يمكن حذفه. يرجى حذف الأصول، ثم محاولة الحذف مرة أخرى. ',
    'invalid_category_type' => 'The category must be an asset category.',

    'create' => array(
        'error'   => 'لم يتم انشاء الموديل، يرجى إعادة المحاولة.',
        'success' => 'تم إنشاء الموديل بنجاح.',
        'duplicate_set' => 'يوجد مسبقا موديل بهذا الاسم، الشركة المصنعة ورقم الموديل.',
    ),

    'update' => array(
        'error'   => 'لم يتم تحديث الموديل، يرجى إعادة المحاولة',
        'success' => 'تم تحديث الموديل بنجاح.',
    ),

    'delete' => array(
        'confirm'   => 'هل تريد بالتأكيد حذف موديل الأصل هذا؟',
        'error'   => 'حدثت مشكلة أثناء حذف الموديل. حاول مرة اخرى.',
        'success' => 'تم حذف الموديل بنجاح.'
    ),

    'restore' => array(
        'error'   		=> 'لم تتم استعادة الموديل، يرجى إعادة المحاولة',
        'success' 		=> 'تم إستعادة الموديل بنجاح.'
    ),

    'bulkedit' => array(
        'error'   		=> 'لم يتم تغيير أي حقول، لذلك لم يتم تحديث أي شيء.',
        'success' 		=> 'تم تحديث النموذج بنجاح. |تم تحديث :model_count نموذج بنجاح.',
        'warn'          => 'أنت على وشك تحديث خصائص النموذج التالي:<unk> أنت على وشك تعديل الخصائص التالية لـ :model_count models:',

    ),

    'bulkdelete' => array(
        'error'   		    => 'لم يتم اختيار أي موديلات، لذلك لم يتم حذف أي شيء.',
        'success' 		    => 'تم حذف النموذج!|تم حذف :success_count نموذج!',
        'success_partial' 	=> 'تم حذف:success_count: من الموديلات، ومع ذلك تعذر حذف fail_count: نظرًا لأنها لا تزال تحتوي على أصول مقترنة بها.'
    ),

);
